@@ -46,8 +46,7 @@ class UniprotStore():
                     gene_name=prot.geneName,
                     taxid=prot.taxid,
                     sequence=prot.sequence,
-                    go = gos,
-                    subcellular_location = prot.subcellular_location)
+                    go = gos)
             except ValidationError as e:
                 print(f"Validation failed for {prot.id}: {str(e)}", file=stderr)
                 continue
